@@ -5,6 +5,18 @@
   else x
 }
 
+#' Check if a vector of packages are available
+#'
+#' @param x a character vector of package names
+#' @keywords internal
+check_pkg_suggests <- function(x) {
+  missing_pkgs <- !vapply(x, requireNamespace, FUN.VALUE = logical(1), quietly = TRUE)
+
+  if (any(missing_pkgs))
+    cli::cli_abort('Missing packages: {paste("`", x[missing_pkgs], "`", sep = "", collapse = ", ")}')
+}
+
+
 #' Modify object classes
 #'
 #' Appends classes to exist object classes. This is utilized to aid in adding a list class to objects created by spdep. This enables to use of the returned objects within data frames and tibbles.
@@ -27,6 +39,7 @@ class_modify <- function(x, class = "list") {
 #' @export
 #' @examples
 #' recreate_listw(guerry_nb$nb, guerry_nb$wt)
+#' @returns a `listw` object
 recreate_listw <- function(nb, wt) {
   which_style <- c(attr(wt, "W") %||% NA,
                    attr(wt, "B") %||% NA,
@@ -97,6 +110,7 @@ cond_permute_nb <- function(nb, seed = NULL) {
 #' @param a listw object.
 #'
 #' @keywords internal
+#' @returns a `listw` object
 permute_listw <- function(listw) {
   n <- length(listw$neighbours)
 
@@ -116,6 +130,7 @@ permute_listw <- function(listw) {
 #'
 #' @param i the index position of observation `i`
 #' @keywords internal
+#' @returns a `nb` class object
 shuffle_nbs <- function(i, n, card) {
   x <- 1:n
   sample(x[-i], size = card)
